@@ -1,6 +1,5 @@
 from typing import List, Optional
 
-from django.contrib.auth import get_user_model
 from django.db.models import Model
 from nwon_baseline.typings import AnyDict
 
@@ -11,8 +10,6 @@ from nwon_django_toolbox.typings.permission_test_expectation import (
 )
 from nwon_django_toolbox.url_helper import detail_url_for_model, list_url_for_model
 
-User = get_user_model()
-
 
 def test_permissions(
     model: Model,
